@@ -1,14 +1,27 @@
 import numpy as np
 
 
-def conv_vti_thoms2cij(rho, vp, vs, delT=None, epsT=None, gamT=None):
+def conv_vti_thoms2cij(rho, vp, vs, delT=[], epsT=[], gamT=[]):
+    
+    # print(vp[:5])
+    # print(delT[:5])
 
-    if delT is None:
-        delT = np.zeros(np.shape(rho))
-    if epsT is None:
-        epsT = np.zeros(np.shape(rho))
-    if gamT is None:
-        gamT = np.zeros(np.shape(rho))
+    # if delT is None:
+    #     delT = np.zeros(np.shape(rho))
+    # if epsT is None:
+    #     epsT = np.zeros(np.shape(rho))
+    # if gamT is None:
+    #     gamT = np.zeros(np.shape(rho))
+        
+    # include anisotropy
+    nn = len(rho)
+    if len(delT) == 0:
+        delT = np.zeros(nn)
+    if len(epsT) == 0:
+        epsT = np.zeros(nn)
+    if len(gamT) == 0:
+        gamT = np.zeros(nn)
+        
 
     c33 = rho * vp ** 2
     c44 = rho * vs ** 2
